@@ -146,7 +146,7 @@ addSpace <- function(x) ifelse(x != "1", "[5pt]","")
 #  
 #  # modify this for your own computer file structure:
 #  savePath<-"/Users/rhirsch/Desktop/"
-#  saveResults(savePath, INFO)
+#  saveResults(savePath, eList)
 
 ## ----openDataRetrieval, eval=FALSE------------------------
 #  library(dataRetrieval)
@@ -312,6 +312,10 @@ eList <- eListColumbia
 ## ----newChunck, echo=TRUE,eval=TRUE-----------------------
 eList <- setPA(eList)
 
+## ----plotSingleandSD, echo=TRUE, fig.cap="Plots of discharge statistics",fig.subcap=c("plotFlowSingle(eList, istat=5,qUnit='thousandCfs')","plotSDLogQ(eList)"),out.width='.5\\linewidth',out.height='.5\\linewidth',fig.show='hold',fig.pos="h",cache=TRUE----
+plotFlowSingle(eList, istat=5,qUnit="thousandCfs")
+plotSDLogQ(eList)
+
 ## ----Merced, echo=TRUE,eval=FALSE-------------------------
 #  # Merced River at Happy Isles Bridge, CA:
 #  siteNumber<-"11264500"
@@ -338,6 +342,9 @@ plotFlowSingle(eListMerced,istat=5,qMax=200)
 ## ----plotFour, echo=TRUE, fig.cap="\\texttt{plotFour(eListMerced, qUnit=3)}",fig.show='asis',out.width='1\\linewidth',out.height='1\\linewidth',fig.pos="h"----
 plotFour(eListMerced, qUnit=3)
 
+## ----plotFourStats,echo=TRUE, fig.cap="\\texttt{plotFourStats(eListMerced, qUnit=3)}",fig.show='asis',out.width='1\\linewidth',out.height='1\\linewidth',fig.pos="h",cache=TRUE----
+plotFourStats(eListMerced, qUnit=3)
+
 ## ----MississippiData, echo=TRUE,eval=FALSE----------------
 #  #Mississippi River at Keokuk Iowa:
 #  siteNumber<-"05474500"
@@ -412,7 +419,7 @@ flowDuration(eList, qUnit=1, centerDate="09-30", span=30)
 ## ----wrtds5, eval=FALSE, echo=TRUE------------------------
 #  #An example directory name
 #  savePath <- "C:/Users/egretUser/WRTDS_Output/"
-#  saveResults(savePath, INFO)
+#  saveResults(savePath, eList)
 
 ## ----wrtds8, eval=FALSE, echo=TRUE------------------------
 #  loadPath <- "C:/Users/egretUser/WRTDS_Output/"
